@@ -1,5 +1,5 @@
 {-
-Copyright:  (c) 2018-2020 Kowainik
+Copyright:  (c) 2018-2022 Kowainik
 SPDX-License-Identifier: MPL-2.0
 Maintainer: Kowainik <xrom.xkov@gmail.com>
 
@@ -23,4 +23,6 @@ main = doctest
     : "-XRecordWildCards"
     : "-XScopedTypeVariables"
     : "-XTypeApplications"
-    : [ "src/Validation.hs" ]
+    : [ "src/Validation.hs"
+      , "src/Validation/Combinators.hs"
+      ]
